# InvPlaybookTaskData

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**add_after** | **bool** |  | [optional] 
**automation_script** | **str** |  | [optional] 
**description** | **str** |  | [optional] 
**name** | **str** |  | [optional] 
**neighbor_inv_pb_task_id** | **str** |  | [optional] 
**script_arguments** | [**dict(str, AdvanceArg)**](AdvanceArg.md) |  | [optional] 
**tags** | **list[str]** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


